@@ -1,16 +1,13 @@
-use crate::{error::Error, money::Currency, ContextProvider};
+use crate::{error::Error, money::Currency, Context, ContextProvider};
 pub use checkout_server_derive::Server;
 use dropshot::{ApiDescription, HttpServerStarter, ServerContext};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-pub trait Server: ContextProvider {
+pub trait Server<'a, T: Context>: ContextProvider<'a, T> {
     type Context: ServerContext;
-    fn api_description() -> ApiDescription<<Self as Server>::Context>;
-    fn new_server(
-        self,
-        bind_address: &str,
-    ) -> Result<HttpServerStarter<<Self as Server>::Context>, Error>;
+    fn api_description() -> ApiDescription<Self::Context>;
+    fn new_server(self, bind_address: &str) -> Result<HttpServerStarter<Self::Context>, Error>;
 }
 
 #[derive(Serialize, Deserialize, JsonSchema)]
